function [erxfin,eryfin]=trace_clothoide(S,k,ngra,ngracar,ncer,choix);



% trac de la clothode de l'origine  une valeur non nulle (S)
%
%
% [erxfin,eryfin]=trace_clothoide(S,k,ngra,ngracar,ncer,choix) : 
%  
%
% * variables d'entres : 
%    *  S : dernire valeur de l'abscisse curviligne.  
%    *  k : valeur de k 
%    *  ngra : nombre de points pour la graphique (suprieur ou gal  1)  
%    *  ngracar :  nombre de points pour o sont trac les cercles de courbure (suprieur ou gal  zro)  
%    *  ncer : nombre de points pour les cercles  
%     * choix : entier : - si choix=1, utilisation du symbolique 
%                          (plus long, mais plus prcis)
%                        - sinon utilisation de la fonction d'intgration numrique de matlab quadl
%                          (plus rapide, mais moins prcis pour les grandes valeurs de S)   
% * variables de sortie :
%     * erxfin et eryfin : diffrence entre les valeurs finales en x et y et sqrt(pi/2))/2
%                          (nulles pour S tendant vers l'infini).
%
%
% ************ Fonctions auxiliaires utilises ************
%
%     calcul_cossind
%
% *********************************************************
%
% (c) 2005 by      Jrme BASTIEN,
%                  UTBM, Dpartement GMC, Belfort
%                  E-Mail : jerome.bastien@utbm.fr

if (ngra<=1)
   error('  attention, le troisime argument est infrieur ou gal  1');
end
X=zeros(1,ngra);
Y=zeros(1,ngra);
somx=0;
somy=0;
h=S/(ngra-1);
for i=2:ngra
   [somauxix,somauxiy]=calcul_cossind(choix,((i-2)*h)/k,((i-1)*h)/k);
   somx=somauxix+somx;
   somy=somauxiy+somy;
   X(i)=k*somx;
   Y(i)=k*somy;
end
erxfin=abs(X(end)-(sqrt(pi/2))/2);
eryfin=abs(Y(end)-(sqrt(pi/2))/2);
if (ngracar~=0)
   Xacar=zeros(1,ngracar);
   Yacar=zeros(1,ngracar);
   somx=0;
   somy=0;
   h=S/ngracar;
   scar=(1:ngracar)*h;
   for i=1:ngracar
      [somauxix,somauxiy]=calcul_cossind(choix,((i-1)*h)/k,(i*h)/k);
      somx=somauxix+somx;
      somy=somauxiy+somy;
      Xacar(i)=k*somx;
      Yacar(i)=k*somy;
   end
   Ncarx=-sin(scar.^2/k^2);
   Ncary=cos(scar.^2/k^2);
   Rcar=(k^2)./(2*scar);
   Xcar=Xacar+Rcar.*Ncarx;
   Ycar=Yacar+Rcar.*Ncary;
   %  otpimiser par calcul vectoriel et calcul de tableau rectangulaire ?
   [thetacar,oublie]=cart2pol(-Ncarx,-Ncary);
   xcercle=zeros(ngracar,ncer);
   ycercle=zeros(ngracar,ncer);
   for ll=1:ngracar-1
      xcercle(ll,:)=Xcar(ll)+Rcar(ll)*cos(-linspace(-pi/2,pi/2,ncer)*scar(ll)+thetacar(ll));    
      ycercle(ll,:)=Ycar(ll)+Rcar(ll)*sin(-linspace(-pi/2,pi/2,ncer)*scar(ll)+thetacar(ll));    
   end
   xcercle(end,:)=Xcar(end)+Rcar(end)*cos(-linspace(-pi/2,pi/2,ncer)+thetacar(end));    
   ycercle(end,:)=Ycar(end)+Rcar(end)*sin(-linspace(-pi/2,pi/2,ncer)+thetacar(end));    
end

clf;
hold on;
axis equal;
plot(X,Y,'b');
if (ngracar~=0)
   plot(Xacar,Yacar,'o',Xcar,Ycar,'o');
   plot([Xacar;Xcar],[Yacar;Ycar],'r');
   plot(xcercle(end,:),ycercle(end,:),'r');
   plot((xcercle(1:end-1,:)).',(ycercle(1:end-1,:)).','-.k');
end
plot(X,Y,'b');
if (ngracar~=0)
   legend('clothode','point caractristique','centre de courbure','cercle de sortie',0);
end
hold off;
